@@ -65,7 +65,7 @@ class NamespaceConfig(object):
         return (parsed.netloc + parsed.path).replace('/', os.path.sep)
 
     @property
-    def accounts_dir(self):  # pylint: disable=missing-docstring
+    def accounts_dir(self):  # pylint: disable=missing-function-docstring
         return self.accounts_dir_for_server_path(self.server_path)
 
     def accounts_dir_for_server_path(self, server_path):
@@ -75,23 +75,23 @@ class NamespaceConfig(object):
             self.namespace.config_dir, constants.ACCOUNTS_DIR, server_path)
 
     @property
-    def backup_dir(self):  # pylint: disable=missing-docstring
+    def backup_dir(self):  # pylint: disable=missing-function-docstring
         return os.path.join(self.namespace.work_dir, constants.BACKUP_DIR)
 
     @property
-    def csr_dir(self):  # pylint: disable=missing-docstring
+    def csr_dir(self):  # pylint: disable=missing-function-docstring
         return os.path.join(self.namespace.config_dir, constants.CSR_DIR)
 
     @property
-    def in_progress_dir(self):  # pylint: disable=missing-docstring
+    def in_progress_dir(self):  # pylint: disable=missing-function-docstring
         return os.path.join(self.namespace.work_dir, constants.IN_PROGRESS_DIR)
 
     @property
-    def key_dir(self):  # pylint: disable=missing-docstring
+    def key_dir(self):  # pylint: disable=missing-function-docstring
         return os.path.join(self.namespace.config_dir, constants.KEY_DIR)
 
     @property
-    def temp_checkpoint_dir(self):  # pylint: disable=missing-docstring
+    def temp_checkpoint_dir(self):  # pylint: disable=missing-function-docstring
         return os.path.join(
             self.namespace.work_dir, constants.TEMP_CHECKPOINT_DIR)
 
@@ -102,15 +102,15 @@ class NamespaceConfig(object):
         return type(self)(new_ns)
 
     @property
-    def default_archive_dir(self):  # pylint: disable=missing-docstring
+    def default_archive_dir(self):  # pylint: disable=missing-function-docstring
         return os.path.join(self.namespace.config_dir, constants.ARCHIVE_DIR)
 
     @property
-    def live_dir(self):  # pylint: disable=missing-docstring
+    def live_dir(self):  # pylint: disable=missing-function-docstring
         return os.path.join(self.namespace.config_dir, constants.LIVE_DIR)
 
     @property
-    def renewal_configs_dir(self):  # pylint: disable=missing-docstring
+    def renewal_configs_dir(self):  # pylint: disable=missing-function-docstring
         return os.path.join(
             self.namespace.config_dir, constants.RENEWAL_CONFIGS_DIR)
 
